package com.usky.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.exception.BusinessException;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.system.domain.SysTenantConfig;
import com.usky.system.domain.SysTenantPlatform;
import com.usky.system.mapper.SysTenantPlatformMapper;
import com.usky.system.service.SysPlatformService;
import com.usky.system.service.SysTenantPlatformService;
import com.usky.system.service.vo.SysPlatformVo;
import com.usky.system.service.vo.TenantPlatformListVo;
import com.usky.system.service.vo.TenantPlatformVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 租户和应用关联表 服务实现类
 * </p>
 *
 * @author han
 * @since 2024-08-14
 */
@Service
public class SysTenantPlatformServiceImpl extends AbstractCrudService<SysTenantPlatformMapper, SysTenantPlatform> implements SysTenantPlatformService {

    @Autowired
    private SysPlatformService sysPlatformService;

    @Override
    @Transactional
    public void updateTenantPlatform(TenantPlatformVo tenantPlatformVo) {
        Integer[] arr = tenantPlatformVo.getPlatformIds();
        if (tenantPlatformVo.getRequestId().equals(0)){
            SysTenantPlatform sysTenantPlatform = new SysTenantPlatform();
            sysTenantPlatform.setTenantId(tenantPlatformVo.getTenantId());
            sysTenantPlatform.setPlatformId(arr[0]);
            sysTenantPlatform.setIsDefault(1);
            this.save(sysTenantPlatform);
        }else {
            LambdaQueryWrapper<SysTenantPlatform> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.eq(SysTenantPlatform::getTenantId,tenantPlatformVo.getTenantId())
                    .ne(SysTenantPlatform::getIsDefault,1);
            this.remove(queryWrapper);
            LambdaQueryWrapper<SysTenantPlatform> queryWrapper1 = Wrappers.lambdaQuery();
            queryWrapper1.eq(SysTenantPlatform::getTenantId,tenantPlatformVo.getTenantId())
                    .eq(SysTenantPlatform::getIsDefault,1);
            List<SysTenantPlatform> list = this.list(queryWrapper1);
            if (list.size()<=0){
                throw new BusinessException("不允许操作超级管理员用户");
            }
            for (int i = 0; i < arr.length; i++){
                if (!arr[i].equals(list.get(0).getPlatformId())){
                    SysTenantPlatform sysTenantPlatform1 = new SysTenantPlatform();
                    sysTenantPlatform1.setPlatformId(arr[i]);
                    sysTenantPlatform1.setTenantId(tenantPlatformVo.getTenantId());
                    sysTenantPlatform1.setIsDefault(0);
                    this.save(sysTenantPlatform1);
                }
            }
        }
    }

    @Override
    public List<TenantPlatformListVo> getTenantPlatformList(Integer tenantId) {
        List<TenantPlatformListVo> list2 = new ArrayList<>();;
        LambdaQueryWrapper<SysTenantPlatform> queryWrapper1 = Wrappers.lambdaQuery();
        queryWrapper1.eq(SysTenantPlatform::getTenantId,tenantId);
        List<SysTenantPlatform> list = this.list(queryWrapper1);
        List<SysPlatformVo> list1 = sysPlatformService.getPlatformAllList();
        if(CollectionUtils.isNotEmpty(list1)){
            for(int i=0;i<list1.size();i++){
                TenantPlatformListVo tenantPlatformListVo = new TenantPlatformListVo();
                tenantPlatformListVo.setPlatformName(list1.get(i).getPlatformName());
                tenantPlatformListVo.setPlatformId(list1.get(i).getId());
                tenantPlatformListVo.setIcon(list1.get(i).getIcon());
                tenantPlatformListVo.setIsDefault(0);
                tenantPlatformListVo.setIsSelected(0);
                if(CollectionUtils.isNotEmpty(list)){
                    for(int j=0;j<list.size();j++){
                        if (list1.get(i).getId().equals(list.get(j).getPlatformId())){
                            tenantPlatformListVo.setIsDefault(list.get(j).getIsDefault());
                            tenantPlatformListVo.setIsSelected(1);
                        }
                    }
                }
                list2.add(tenantPlatformListVo);
            }
        }
        return list2;
    }
}
